--  Copyright 2015-2023 Free Software Foundation, Inc.
--
--  This program is free software; you can redistribute it and/or modify
--  it under the terms of the GNU General Public License as published by
--  the Free Software Foundation; either version 3 of the License, or
--  (at your option) any later version.
--
--  This program is distributed in the hope that it will be useful,
--  but WITHOUT ANY WARRANTY; without even the implied warranty of
--  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
--  GNU General Public License for more details.
--
--  You should have received a copy of the GNU General Public License
--  along with this program.  If not, see <http://www.gnu.org/licenses/>.

with Pck; use Pck;

procedure Foo_O115_002 is
   My_Object : Object := (N => 3, Data => (3, 5, 8));
   My_Small_Object : Small_Object := (N => 3, Data => (3, 5, 8));
begin
   Do_Nothing (My_Object'Address);             -- STOP
   Do_Nothing (My_Small_Object'Address);
end Foo_O115_002;

